# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _

from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin
from . import models


class GenericTemplateAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('title',)
    advanced_search_fields = (
        ('title__icontains',),
        ('status',),
        ('language', 'extension',),
        ('content__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('title', 'slug', 'language', 'extension', 'content',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'title', 'extension', 'language', 'status', 'ordering')
    list_display_links = ('title',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('language',)
    prepopulated_fields = {'slug': ('title',)}


class EmailTemplateAdmin(GenericTemplateAdmin):
    advanced_search_fields = (
        ('title__icontains',),
        ('status',),
        ('language', 'extension',),
        ('subject__icontains',),
        ('content__icontains',),
    )
    fieldsets = (
        (_('general information'), {
            'fields': ('title', 'slug', 'subject', 'language', 'extension', 'content',)
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'title', 'subject', 'extension', 'language', 'status', 'ordering')


admin.site.register(models.GenericTemplate, GenericTemplateAdmin)
admin.site.register(models.EmailTemplate, EmailTemplateAdmin)
